from setuptools import setup

setup(
    name="dsnd_probability_acm",
    version="0.1",
    description="Gaussian distributions",
    packages=["dsnd_probability_acm"],
    zip_safe=False,
    install_requires=["matplotlib"],
)
